@@ -21,8 +21,7 @@
 #ifndef GOG_PLOT_ENGINE_H
 #define GOG_PLOT_ENGINE_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -51,11 +50,12 @@ GHashTable const *gog_plot_families (void);
 GogPlotFamily *gog_plot_family_by_name  (char const *name);
 GogPlotFamily *gog_plot_family_register (char const *name, char const *sample_image_file,
 					 int priority, GogAxisSet axis_set);
+void gog_plot_family_unregister (GogPlotFamily *family);
 GogPlotType   *gog_plot_type_register   (GogPlotFamily *famlily, int col, int row,
 					 char const *name, char const *sample_image_file,
 					 char const *description, char const *engine);
 
-struct _GogRegCurveType {
+struct _GogTrendLineType {
 	char *engine;
 
 	char *name;
@@ -64,10 +64,10 @@ struct _GogRegCurveType {
 	GHashTable *properties;
 };
 
-GHashTable const *gog_reg_curve_types (void);
+GHashTable const *gog_trend_line_types (void);
 
-void gog_plugin_services_init (void);
-void gog_plugin_services_shutdown (void);
+void _gog_plugin_services_init (void);
+void _gog_plugin_services_shutdown (void);
 
 G_END_DECLS
 
