@@ -25,30 +25,25 @@
 #include <goffice/graph/gog-series-impl.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-object-xml.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
+#include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <glib/gi18n-lib.h>
 
 #ifdef GOFFICE_WITH_GTK
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktable.h>
+#include <gtk/gtk.h>
 #endif
 
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
-#define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_PLOT_TYPE, GogPlotClass))
+#define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_PLOT, GogPlotClass))
 
 enum {
 	PLOT_PROP_0,
@@ -86,13 +81,6 @@ role_series_can_add (GogObject const *parent)
 	return g_slist_length (plot->series) < plot->desc.num_series_max;
 }
 
-static gboolean
-role_series_can_remove (GogObject const *child)
-{
-	GogPlot const *plot = GOG_PLOT (child->parent);
-	return g_slist_length (plot->series) > plot->desc.num_series_min;
-}
-
 static GogObject *
 role_series_allocate (GogObject *plot)
 {
@@ -100,7 +88,7 @@ role_series_allocate (GogObject *plot)
 	GType type = klass->series_type;
 
 	if (type == 0)
-		type = GOG_SERIES_TYPE;
+		type = GOG_TYPE_SERIES;
 	return g_object_new (type, NULL);
 }
 
@@ -148,7 +136,7 @@ role_series_pre_remove (GogObject *parent, GogObject *series)
 
 #ifdef GOFFICE_WITH_GTK
 typedef struct {
-	GladeXML	*gui;
+	GtkBuilder	*gui;
 	GtkWidget	*x_spin, *y_spin, *w_spin, *h_spin;
 	gulong		 w_spin_signal, h_spin_signal;
 	GtkWidget	*position_select_combo;
@@ -264,18 +252,19 @@ cb_update_editor (GogObject *gobj, PlotPrefState *state)
 
 static void
 gog_plot_populate_editor (GogObject *obj,
-			  GogEditor *editor,
+			  GOEditor *editor,
 			  G_GNUC_UNUSED GogDataAllocator *dalloc,
 			  GOCmdContext *cc)
 {
-	static const char *axis_labels[7] = { 
+	static const char *axis_labels[GOG_AXIS_TYPES] = { 
 		N_("X axis:"), 
 		N_("Y axis:"), 
 		N_("Z axis:"), 
 		N_("Circular axis:"), 
 		N_("Radial axis:"), 
-		N_("Type axis:"), 
-		N_("Pseudo 3D axis:")
+		N_("Pseudo 3D axis:"), 
+		N_("Color axis:"), 
+		N_("Bubble axis:")
 	};
 	
 	GtkWidget *w;
@@ -289,12 +278,12 @@ gog_plot_populate_editor (GogObject *obj,
 	GtkListStore *store;
 	GtkTreeIter iter;
 	GtkCellRenderer *cell;
-	GladeXML *gui;
+	GtkBuilder *gui;
 	PlotPrefState *state;
 	gboolean is_plot_area_manual;
 
 	g_return_if_fail (chart != NULL);
-	gui = go_libglade_new ("gog-plot-prefs.glade", "gog_plot_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new ("gog-plot-prefs.ui", GETTEXT_PACKAGE, cc);
 	g_return_if_fail (gui != NULL);
 
 	state = g_new  (PlotPrefState, 1);
@@ -354,7 +343,7 @@ gog_plot_populate_editor (GogObject *obj,
 			gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 			gtk_container_set_border_width (GTK_CONTAINER (table), 12);
 			gtk_widget_show_all (table);
-			gog_editor_add_page (editor, table, _("Axes"));
+			go_editor_add_page (editor, table, _("Axes"));
 		}
 		else
 			g_object_unref (G_OBJECT (table));
@@ -362,19 +351,19 @@ gog_plot_populate_editor (GogObject *obj,
 	
 	is_plot_area_manual = gog_chart_get_plot_area (chart, &plot_area);
 	
-	state->x_spin = glade_xml_get_widget (gui, "x_spin");
+	state->x_spin = go_gtk_builder_get_widget (gui, "x_spin");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->x_spin), 
 				   plot_area.x * 100.0); 
 	g_signal_connect (G_OBJECT (state->x_spin), "value-changed", 
 			  G_CALLBACK (cb_plot_area_changed), state);
 
-	state->y_spin = glade_xml_get_widget (gui, "y_spin");
+	state->y_spin = go_gtk_builder_get_widget (gui, "y_spin");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->y_spin), 
 				   plot_area.y * 100.0); 
 	g_signal_connect (G_OBJECT (state->y_spin), "value-changed", 
 			  G_CALLBACK (cb_plot_area_changed), state);
 
-	state->w_spin = glade_xml_get_widget (gui, "w_spin");
+	state->w_spin = go_gtk_builder_get_widget (gui, "w_spin");
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (state->w_spin), 
 				   0.0, (1.0 - plot_area.x) * 100.0);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->w_spin), 
@@ -382,7 +371,7 @@ gog_plot_populate_editor (GogObject *obj,
 	state->w_spin_signal = g_signal_connect (G_OBJECT (state->w_spin), "value-changed", 
 						 G_CALLBACK (cb_plot_area_changed), state);
 
-	state->h_spin = glade_xml_get_widget (gui, "h_spin");
+	state->h_spin = go_gtk_builder_get_widget (gui, "h_spin");
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (state->h_spin), 
 				   0.0, (1.0 - plot_area.y) * 100.0);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->h_spin), 
@@ -390,20 +379,19 @@ gog_plot_populate_editor (GogObject *obj,
 	state->h_spin_signal = g_signal_connect (G_OBJECT (state->h_spin), "value-changed", 
 						 G_CALLBACK (cb_plot_area_changed), state);
 
-	state->position_select_combo = glade_xml_get_widget (gui, "position_select_combo");
+	state->position_select_combo = go_gtk_builder_get_widget (gui, "position_select_combo");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (state->position_select_combo), 
 				  is_plot_area_manual ? 1 : 0); 
-	state->manual_setting_table = glade_xml_get_widget (gui, "manual_setting_table");
+	state->manual_setting_table = go_gtk_builder_get_widget (gui, "manual_setting_table");
 	if (!is_plot_area_manual)
 		gtk_widget_hide (state->manual_setting_table);
 	
 	g_signal_connect (G_OBJECT (state->position_select_combo),
 			  "changed", G_CALLBACK (cb_manual_position_changed), state);
 
-	w = glade_xml_get_widget (gui, "gog_plot_prefs");
-	g_object_set_data_full (G_OBJECT (w), "state", state, 
-				(GDestroyNotify) plot_pref_state_free);  
-	gog_editor_add_page (editor, w, _("Plot area"));
+	w = go_gtk_builder_get_widget (gui, "gog_plot_prefs");
+	g_signal_connect_swapped (G_OBJECT (w), "destroy", G_CALLBACK (plot_pref_state_free), state);  
+	go_editor_add_page (editor, w, _("Plot area"));
 
 	state->update_editor_handler = g_signal_connect (G_OBJECT (plot), 
 							 "update-editor", 
@@ -493,7 +481,7 @@ gog_plot_children_reordered (GogObject *obj)
 	GogPlot *plot = GOG_PLOT (obj);
 
 	for (ptr = obj->children; ptr != NULL ; ptr = ptr->next)
-		if (IS_GOG_SERIES (ptr->data))
+		if (GOG_IS_SERIES (ptr->data))
 			accum = g_slist_prepend (accum, ptr->data);
 	g_slist_free (plot->series);
 	plot->series = g_slist_reverse (accum);
@@ -507,7 +495,7 @@ gog_plot_class_init (GogObjectClass *gog_klass)
 	static GogObjectRole const roles[] = {
 		{ N_("Series"), "GogSeries",	0,
 		  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
-		  role_series_can_add, role_series_can_remove,
+		  role_series_can_add, NULL,
 		  role_series_allocate,
 		  role_series_post_add, role_series_pre_remove, NULL },
 	};
@@ -529,25 +517,25 @@ gog_plot_class_init (GogObjectClass *gog_klass)
 			_("Vary style by element"),
 			_("Use a different style for each segments"),
 			FALSE,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_X,
 		g_param_spec_uint ("x-axis", 
 			_("X axis"), 
 			_("Reference to X axis"),
 			0, G_MAXINT, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_Y,
 		g_param_spec_uint ("y-axis", 
 			_("Y axis"), 
 			_("Reference to Y axis"),
 			0, G_MAXINT, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_GROUP,
 		g_param_spec_string ("plot-group", 
 			_("Plot group"), 
 			_("Name of plot group if any"),
 			NULL, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_GURU_HINTS,
 		g_param_spec_string ("guru-hints", 
 			_("Guru hints"), 
@@ -560,7 +548,7 @@ gog_plot_class_init (GogObjectClass *gog_klass)
 			_("Default interpolation"),
 			_("Default type of series line interpolation"),
 			"linear",
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_klass->children_reordered = gog_plot_children_reordered;
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
@@ -582,7 +570,7 @@ gog_plot_init (GogPlot *plot, GogPlotClass const *derived_plot_klass)
 
 GSF_CLASS_ABSTRACT (GogPlot, gog_plot,
 		    gog_plot_class_init, gog_plot_init,
-		    GOG_OBJECT_TYPE)
+		    GOG_TYPE_OBJECT)
 
 GogPlot *
 gog_plot_new_by_type (GogPlotType const *type)
@@ -613,7 +601,7 @@ gog_plot_new_series (GogPlot *plot)
 {
 	GogObject *res;
 
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 
 	res = gog_object_add_by_name (GOG_OBJECT (plot), "Series", NULL);
 	return res ? GOG_SERIES (res) : NULL;
@@ -621,7 +609,7 @@ gog_plot_new_series (GogPlot *plot)
 GogPlotDesc const *
 gog_plot_description (GogPlot const *plot)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	return &plot->desc;
 }
 
@@ -635,7 +623,7 @@ gog_plot_get_chart (GogPlot const *plot)
 void
 gog_plot_request_cardinality_update (GogPlot *plot)
 {
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (plot->cardinality_valid) {
 		GogChart *chart = gog_plot_get_chart (plot);
@@ -661,7 +649,7 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 	gboolean   is_valid;
 	unsigned   size = 0, no_legend = 0, i;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	plot->cardinality_valid = TRUE;
 	plot->index_num = i = index_num;
@@ -677,7 +665,7 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 			gog_series_set_index (series, i++, FALSE);
 			if (!gog_series_has_legend (series))
 				no_legend++;
-		}
+		}			
 	}
 
 	plot->full_cardinality =
@@ -699,7 +687,7 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 void
 gog_plot_get_cardinality (GogPlot *plot, unsigned *full, unsigned *visible)
 {
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (!plot->cardinality_valid)
 		g_warning ("[GogPlot::get_cardinality] Invalid cardinality");
@@ -710,21 +698,28 @@ gog_plot_get_cardinality (GogPlot *plot, unsigned *full, unsigned *visible)
 		*visible = plot->visible_cardinality;
 }
 
+static gboolean
+gog_plot_enum_in_reverse (GogPlot const *plot)
+{
+	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
+	return klass != NULL && klass->enum_in_reverse && (klass->enum_in_reverse) (plot);
+}
+
 void
 gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 		       GogEnumFunc func, gpointer data)
 {
 	GSList *ptr;
 	GogSeries const *series;
-	GogStyle *style, *tmp_style;
-	GODataVector *labels;
+	GOStyle *style, *tmp_style;
+	GOData *labels;
 	unsigned i, n, num_labels = 0;
 	char *label = NULL;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
 	GList *overrides;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 	if (!plot->cardinality_valid)
 		gog_plot_get_cardinality (plot, NULL, NULL);
 
@@ -738,23 +733,32 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 		return;
 
 	if (!plot->vary_style_by_element) {
+		GSList *tmp = NULL;
+
 		unsigned i = plot->index_num;
+
+		if (gog_plot_enum_in_reverse (plot))
+			ptr = tmp = g_slist_reverse (g_slist_copy (ptr));
+
 		for (; ptr != NULL ; ptr = ptr->next)
 			if (!only_visible || gog_series_has_legend (ptr->data)) {
-				func (i, gog_styled_object_get_style (ptr->data),
+				func (i, go_styled_object_get_style (ptr->data),
 				      gog_object_get_name (ptr->data), data);
 				i++;
 			}
+
+		g_slist_free (tmp);
+
 		return;
 	}
 
 	series = ptr->data; /* start with the first */
 	labels = NULL;
 	if (series->values[0].data != NULL) {
-		labels = GO_DATA_VECTOR (series->values[0].data);
-		num_labels = go_data_vector_get_len (labels);
+		labels = series->values[0].data;
+		num_labels = go_data_get_vector_size (labels);
 	}
-	style = gog_style_dup (series->base.style);
+	style = go_style_dup (series->base.style);
 	n = only_visible ? plot->visible_cardinality : plot->full_cardinality;
 	for (overrides = series->overrides, i = 0; i < n ; i++) {
 		if (overrides != NULL &&
@@ -767,8 +771,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 		gog_theme_fillin_style (theme, tmp_style, GOG_OBJECT (series),
 			plot->index_num + i, FALSE);
 		if (labels != NULL)
- 			label = (i < num_labels)
- 				? go_data_vector_get_str (labels, i) : g_strdup ("");
+			label = (i < num_labels) ? go_data_get_vector_string (labels, i) : g_strdup ("");
 		else
 			label = NULL;
 		if (label == NULL)
@@ -788,7 +791,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 GSList const *
 gog_plot_get_series (GogPlot const *plot)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	return plot->series;
 }
 
@@ -800,7 +803,7 @@ gog_plot_get_series (GogPlot const *plot)
  *
  * Queries @plot for its axis preferences for @axis and stores the results in
  * @bounds.  All elements of @bounds are initialized to sane values before the
- * query _ACCEPT_ ::fmt.  The caller is responsible for initializing it.  This
+ * query _EXCEPT_ ::fmt.  The caller is responsible for initializing it.  This
  * is done so that once on plot has selected a format the others need not do
  * the lookup too if so desired.
  *
@@ -823,6 +826,8 @@ gog_plot_get_axis_bounds (GogPlot *plot, GogAxisType axis,
 	bounds->logical.minima = go_nan;
 	bounds->is_discrete = FALSE;
 	bounds->center_on_ticks = TRUE;
+	bounds->date_conv = NULL;
+
 	if (klass->axis_get_bounds == NULL)
 		return NULL;
 	return (klass->axis_get_bounds) (plot, axis, bounds);
@@ -869,8 +874,8 @@ void
 gog_plot_set_axis (GogPlot *plot, GogAxis *axis)
 {
 	GogAxisType type;
-	g_return_if_fail (IS_GOG_PLOT (plot));
-	g_return_if_fail (IS_GOG_AXIS (axis));
+	g_return_if_fail (GOG_IS_PLOT (plot));
+	g_return_if_fail (GOG_IS_AXIS (axis));
 
 	type = gog_axis_get_atype (axis);
 	g_return_if_fail (type != GOG_AXIS_UNKNOWN);
@@ -895,7 +900,7 @@ gog_plot_set_axis_by_id (GogPlot *plot, GogAxisType type, unsigned id)
 	if (id == 0)
 		return FALSE;
 
-	g_return_val_if_fail (IS_GOG_PLOT (plot), FALSE);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), FALSE);
 	g_return_val_if_fail (GOG_OBJECT (plot)->parent != NULL, FALSE);
 
 	chart = gog_plot_get_chart (plot);
@@ -956,7 +961,7 @@ gog_plot_axis_clear (GogPlot *plot, GogAxisSet filter)
 {
 	GogAxisType type;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	for (type = 0 ; type < GOG_AXIS_TYPES ; type++)
 		if (plot->axis[type] != NULL && ((1 << type) & filter)) {
@@ -976,7 +981,7 @@ gog_plot_get_axis_id (GogPlot const *plot, GogAxisType type)
 GogAxis	*
 gog_plot_get_axis (GogPlot const *plot, GogAxisType type)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	g_return_val_if_fail (type < GOG_AXIS_TYPES, NULL);
 	g_return_val_if_fail (GOG_AXIS_UNKNOWN < type, NULL);
 	return plot->axis[type];
@@ -986,7 +991,7 @@ void
 gog_plot_update_3d (GogPlot *plot)
 {
 	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (klass->update_3d)
 		klass->update_3d (plot);
@@ -998,10 +1003,10 @@ gog_plot_guru_helper_add_grid_line (GogPlot *plot, gboolean major)
 	GogAxisType type;
 
 	for (type = 0; type < GOG_AXIS_TYPES; type++) {
-		if (((type & (GOG_AXIS_X | 
-			    GOG_AXIS_Y | 
-			    GOG_AXIS_CIRCULAR | 
-			    GOG_AXIS_RADIAL)) != 0) &&
+		if ((((type == GOG_AXIS_X) | 
+		      (type == GOG_AXIS_Y) | 
+		      (type == GOG_AXIS_CIRCULAR) | 
+		      (type == GOG_AXIS_RADIAL))) &&
 		    plot->axis[type] != NULL &&
 		    gog_axis_get_grid_line (plot->axis[type], major) == NULL)
 		{
@@ -1019,7 +1024,7 @@ gog_plot_guru_helper (GogPlot *plot)
 	char *hint;
 	unsigned i;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 	klass = GOG_PLOT_GET_CLASS (plot);
 
 	if (plot->guru_hints == NULL)
@@ -1044,6 +1049,15 @@ gog_plot_guru_helper (GogPlot *plot)
 	g_strfreev (hints);
 }
 
+void gog_plot_clear_series (GogPlot *plot)
+{
+	while (plot->series) {
+		GogObject *gobj = GOG_OBJECT (plot->series->data);
+		gog_object_clear_parent (gobj);
+		g_object_unref (gobj);
+	}
+}
+
 /*****************************************************************************/
 
 #ifdef GOFFICE_WITH_GTK
@@ -1206,4 +1220,4 @@ gog_plot_view_class_init (GogPlotViewClass *pview_klass)
 
 GSF_CLASS_ABSTRACT (GogPlotView, gog_plot_view,
 		    gog_plot_view_class_init, NULL,
-		    GOG_VIEW_TYPE)
+		    GOG_TYPE_VIEW)
