@@ -27,8 +27,7 @@
 #include <goffice/gtk/go-color-group.h>
 
 #include <glib/gi18n-lib.h>
-#include <gtk/gtkcolorsel.h>
-#include <gtk/gtkcolorseldialog.h>
+#include <gtk/gtk.h>
 
 extern GONamedColor default_color_set [];
 
@@ -352,12 +351,13 @@ go_color_selector_set_color (GOSelector *selector, GOColor color)
 /**
  * go_color_selector_get_color:
  * @selector: a #GOSelector
+ * @is_auto : non-NULL result storage
  * 
  * Retrieves current color selection of a #GOSelector 
  * created via @go_color_selector_new. @is_auto will be set to
  * TRUE if current selection was set by clicking on automatic palette item.
  *
- * return current color selection.
+ * Returns: current color selection.
  **/
 GOColor 
 go_color_selector_get_color (GOSelector *selector, gboolean *is_auto)
@@ -384,7 +384,7 @@ go_color_selector_get_color (GOSelector *selector, gboolean *is_auto)
 /**
  * go_color_selector_set_allow_alpha :
  * @selector : #GOColorSelector
- * @allow_alpha : 
+ * @allow_alpha : boolean
  *
  * Should the custom colour selector allow the use of opacity.
  **/
